powered by
The US Forest Service AirFire group maintains an archive of processed monitoring data. The base URL for this archive is used as the default in all ~_load() functions.
~_load()
"https://airfire-data-exports.s3.us-west-2.amazonaws.com/monitoring/v2"
AirFire_S3_archiveBaseUrl
A url