Learn R Programming

AirMonitor (version 0.4.2)

addAQILines: Add AQI lines to a plot

Description

Draws AQI lines across a plot at the levels appropriate for The monitor_timeseriesPlot function uses this function internally when specifying addAQI = TRUE. pollutant.

Usage

addAQILines(
  pollutant = c("PM2.5", "CO", "OZONE", "PM10", "AQI"),
  palette = c("EPA", "subdued", "deuteranopia"),
  NAAQS = c("PM2.5_2024", "PM2.5"),
  ...
)

Value

No return value, called to add lines to a time series plot.

Arguments

pollutant

EPA AQS criteria pollutant.

palette

Named color palette to use for AQI categories.

NAAQS

Version of NAAQS levels to use. See Note.

...

additional arguments to be passed to abline()