Learn R Programming

AirMonitor (version 0.4.2)

monitor_aqi: Calculate hourly NowCast-based AQI values

Description

Nowcast and AQI algorithms are applied to the data in the monitor object. A modified mts_monitor object is returned whre values have been replaced with their Air Quality Index equivalents. See monitor_nowcast.

Usage

monitor_aqi(
  monitor,
  version = c("pm", "pmAsian", "ozone"),
  includeShortTerm = FALSE,
  NAAQS = c("PM2.5_2024", "PM2.5")
)

Value

A modified mts_monitor object containing AQI values. (A list with meta and data dataframes.)

Arguments

monitor

mts_monitor object.

version

Name of the type of nowcast algorithm to be used.

includeShortTerm

Logical specifying whether to alcluate preliminary NowCast values starting with the 2nd hour.

NAAQS

Version of NAAQS levels to use. See Note.

References

https://en.wikipedia.org/wiki/Nowcast_(Air_Quality_Index)

https://www.airnow.gov/aqi/aqi-basics/