Learn R Programming

AirMonitor (version 0.4.2)

monitor_bestTimezone: Return the most common timezone

Description

Evaluates all timezones in monitor and returns the most common one. In the case of a tie, the alphabetically first one is returned.

Usage

monitor_bestTimezone(monitor = NULL)

Value

A valid base::OlsonNames() timezone.

Arguments

monitor

mts_monitor object.