Learn R Programming

AirMonitor (version 0.4.2)

monitor_select: Subset and reorder time series within an mts_monitor object

Description

This function acts similarly to dplyr::select() working on monitor$data. The returned mts_monitor object will contain only those time series identified by id in the order specified.

This can be helpful when using faceted plot functions based on ggplot such as those found in the AirMonitorPlots package.

Usage

monitor_select(monitor, id)

monitor_reorder(monitor, id)

Value

A reordered (subset) of the incoming mts_monitor object. (A list with meta and data dataframes.)

Arguments

monitor

mts_monitor object.

id

Vector of deviceDeploymentIDs.

See Also

monitor_filterMeta