Learn R Programming

AirMonitor (version 0.4.2)

monitor_timeRange: Get the time range for a monitor

Description

This function is a wrapper for range(monitor$data$datetime) and is convenient for use in data pipelines.

Dates will be returned in the timezone associated with monitor$data$datetime which is typically "UTC" unless timezone is specified.

Usage

monitor_timeRange(monitor = NULL, timezone = NULL)

Value

A vector containing the minimum and maximum times of a mts_monitor object.

Arguments

monitor

mts_monitor object.

timezone

Olson timezone for the returned dates.

Examples

Run this code
Carmel_Valley %>%
  monitor_timeRange(timezone = "America/Los_Angeles")

Run the code above in your browser using DataLab