Invalidates values within a timeseries that appear "sticky".
Some temporary monitoring data has stretches of consecutive values, sometimes
well outside the range of reasonable. This QC function identifies these
"sticky" stretches and returns the original timeseries data with "sticky"
stretches replaced with NA.
QC_invalidateConsecutiveSuspectValues(
x = NULL,
suspectValues = c(0:10 * 1000, NA),
consecutiveCount = 2
)Returns x with some values potentially replaced with NA.
Timeseries data.
Vector of numeric values considered suspect.
How many suspectValues must appear in a row
before they are invalidated.