powered by
Official, US EPA AQI levels, names, colors and action text are provided in a list for easy coloring and labeling.
US_AQI
A list with named elements
Breakpoints are given in units reported for each parameter and include:
breaks_AQI
breaks_CO
breaks_NO2
breaks_OZONE_1hr
breaks_OZONE_8hr
breaks_PM2.5
breaks_PM10
Several different color palettes are provided:
colors_EPA -- official EPA AQI colors
colors_EPA
colors_subdued -- subdued colors fo use with leaflet maps
colors_subdued
colors_deuteranopia -- color vision impaired colors
colors_deuteranopia
Names of AQI categories are provided in several languages identified by the ISO 639-2 alpha-3 code:
names_eng
names_spa
Text for "actions to protect yourself" are provided for each category in several languages identified by the ISO 639-2 alpha-3 code:
actions_eng
actions_spa
Currently supported languages include English (eng) and Spanish (spa).
AQI breaks and colors are defined at https://document.airnow.gov/technical-assistance-document-for-the-reporting-of-daily-air-quailty.pdf and are given in units appropriate for each pollutant.
AQI breaks and associated names and colors
print(US_AQI$breaks_AQI) print(US_AQI$colors_EPA) print(US_AQI$names_eng) print(US_AQI$names_spa)
Run the code above in your browser using DataLab