This function is a convenience wrapper around
graphics::legend(). It will show the AQI colors and
names by default if col and legend are not specified.
AQI categories are arranged with lower levels at the bottom of the legend
to match the arrangement in the plot. This is different from the default
"reading order" so you may wish to reverse the order of user supplied
arguments with rev() .
addAQILegend(
x = "topright",
y = NULL,
pollutant = c("PM2.5", "CO", "OZONE", "PM10", "AQI"),
palette = c("EPA", "subdued", "deuteranopia"),
languageCode = c("eng", "spa"),
NAAQS = c("PM2.5_2024", "PM2.5"),
...
)A list with components rect and text is returned
invisbly. (See legend.)
x Coordinate passed on to the legend() command.
y Coordinate passed on to the legend() command.
EPA AQS criteria pollutant.
Named color palette to use for AQI categories.
ISO 639-2 alpha-3 language code.
Version of NAAQS levels to use. See Note.
Additional arguments to be passed to legend().