Draws AQI lines across a plot at the levels appropriate for
The monitor_timeseriesPlot function uses this function internally when
specifying addAQI = TRUE.
pollutant.
addAQILines(
pollutant = c("PM2.5", "CO", "OZONE", "PM10", "AQI"),
palette = c("EPA", "subdued", "deuteranopia"),
NAAQS = c("PM2.5_2024", "PM2.5"),
...
)No return value, called to add lines to a time series plot.
EPA AQS criteria pollutant.
Named color palette to use for AQI categories.
Version of NAAQS levels to use. See Note.
additional arguments to be passed to abline()