Draws a stacked bar indicating AQI levels on one side of a plot
The monitor_timeseriesPlot function uses this function internally when
specifying addAQI = TRUE.
addAQIStackedBar(
pollutant = c("PM2.5", "CO", "OZONE", "PM10", "AQI"),
palette = c("EPA", "subdued", "deuteranopia"),
width = 0.01,
height = 1,
pos = c("left", "right"),
NAAQS = c("PM2.5_2024", "PM2.5")
)No return value, called to add color bars to a time series plot.
EPA AQS criteria pollutant.
Named color palette to use for AQI categories.
Width of the bar as a fraction of the width of the plot area.
Height of the bar as a fraction of the height of the plot area.
Position of the stacked bar relative to the plot.
Version of NAAQS levels to use. See Note.