coreMetadataNames: Names of standard metadata columns
Description
Vector of names of the required monitor$meta columns.
These represent metadata columns that must exist in every valid
mts_monitor object. Any number of additional columns may also be present.