Nowcast and AQI algorithms are applied to the data in the
monitor object. A modified mts_monitor object is returned whre values
have been replaced with their Air Quality Index equivalents. See monitor_nowcast.
monitor_aqi(
monitor,
version = c("pm", "pmAsian", "ozone"),
includeShortTerm = FALSE,
NAAQS = c("PM2.5_2024", "PM2.5")
)A modified mts_monitor object containing AQI values. (A list
with meta and data dataframes.)
mts_monitor object.
Name of the type of nowcast algorithm to be used.
Logical specifying whether to alcluate preliminary NowCast values starting with the 2nd hour.
Version of NAAQS levels to use. See Note.