Learn R Programming

AirMonitor (version 0.4.2)

monitor_dailyThreshold: Daily counts of values at or above a threshold

Description

Calculates the number of hours per day each time series in monitor was at or above a given threshold.

Because the returned mts_monitor object is defined on a daily axis in a specific time zone, it is important that the incoming monitor contain only timeseries within a single time zone.

Usage

monitor_dailyThreshold(
  monitor = NULL,
  threshold = NULL,
  na.rm = TRUE,
  minHours = 18,
  dayBoundary = c("clock", "LST"),
  NAAQS = c("PM2.5_2024", "PM2.5")
)

Value

A mts_monitor object containing daily counts of hours at or above a threshold value. (A list with meta and data dataframes.)

Arguments

monitor

mts_monitor object.

threshold

AQI level name (e.g. "unhealthy") or numerical threshold at and above which a measurement is counted.

na.rm

Logical value indicating whether NA values should be ignored.

minHours

Minimum number of valid hourly records per day required to calculate statistics. Days with fewer valid records will be assigned NA.

dayBoundary

Treatment of daylight savings time: "clock" uses daylight savings time as defined in the local timezone, "LST" uses "local standard time" all year round.

NAAQS

Version of NAAQS levels to use. See Note.

Examples

Run this code
library(AirMonitor)

# Hours at MODERATE or above
Carmel_Valley %>%
  monitor_dailyThreshold("Moderate") %>%
  monitor_getData()

# Hours at MODERATE or above with the 2024 updated NAAQS
Carmel_Valley %>%
  monitor_dailyThreshold("Moderate", NAAQS = "PM2.5_2024") %>%
  monitor_getData()

# Hours at UNHEALTHY or above
Carmel_Valley %>%
  monitor_dailyThreshold("Unhealthy") %>%
  monitor_getData()

Run the code above in your browser using DataLab