powered by
This function is a wrapper for range(monitor$data$datetime) and is convenient for use in data pipelines.
range(monitor$data$datetime)
Dates will be returned in the timezone associated with monitor$data$datetime which is typically "UTC" unless timezone is specified.
monitor$data$datetime
timezone
monitor_timeRange(monitor = NULL, timezone = NULL)
A vector containing the minimum and maximum times of a mts_monitor object.
mts_monitor object.
Olson timezone for the returned dates.
Carmel_Valley %>% monitor_timeRange(timezone = "America/Los_Angeles")
Run the code above in your browser using DataLab