library(AirMonitor)
# Lane County, Oregon AQSIDs all begin with "41039"
LaneCounty <-
NW_Megafires %>%
monitor_filter(stringr::str_detect(AQSID, '^41039')) %>%
monitor_filterDate(20150801, 20150901)
# Count of hours each site spent in each AQ category in August
LaneCounty %>%
monitor_toAQCTable()
# Count of days each site spent in each AQ
LaneCounty %>%
monitor_dailyStatistic(mean) %>%
monitor_toAQCTable()
# Count of days each site spent in each AQ (simplified names)
siteNames <- c(
"Eugene 1", "Eugene 2", "Eugene 3",
"Springfield", "Oakridge", "Cottage Grove"
)
LaneCounty %>%
monitor_dailyStatistic(mean) %>%
monitor_toAQCTable(siteIdentifier = siteNames)
# Count of days at each AQ level with the new, 2024 NAAQS
LaneCounty %>%
monitor_dailyStatistic(mean) %>%
monitor_toAQCTable(NAAQS = "PM2.5_2024")
Run the code above in your browser using DataLab