Loads pre-generated .rda files containing the most recent WRCC data.
If archiveDataDir is defined, data will be loaded from this local
archive. Otherwise, data will be loaded from the monitoring data repository
maintained by the USFS AirFire team.
The files loaded by this function are updated multiple times an hour and contain data for the previous 10 days.
For daily updates covering the most recent 45 days, use wrcc_loadDaily().
For data extended more than 45 days into the past, use wrcc_loadAnnual().
wrcc_loadLatest(
archiveBaseUrl = paste0("https://airfire-data-exports.s3.us-west-2.amazonaws.com/",
"monitoring/v2"),
archiveBaseDir = NULL,
QC_negativeValues = c("zero", "na", "ignore"),
QC_removeSuspectData = TRUE
)A mts_monitor object with WRCC data. (A list with
meta and data dataframes.)
Base URL for monitoring v2 data files.
Local base directory for monitoring v2 data files.
Type of QC to apply to negative values.
Removes monitors determined to be misbehaving.
wrcc_loadAnnual
wrcc_loadDaily